import React from 'react';
import { Table, Card, Input, Button, Space, Select, DatePicker, Row, Col } from 'antd';
import { SearchOutlined, ReloadOutlined, FilterOutlined } from '@ant-design/icons';
import type { TableProps, ColumnsType } from 'antd/es/table';
import type { QueryParams, PaginationInfo } from '@/types';
import { PAGINATION } from '@/constants';

const { Search } = Input;
const { RangePicker } = DatePicker;

interface DataTableProps<T> extends Omit<TableProps<T>, 'columns' | 'dataSource' | 'pagination'> {
  columns: ColumnsType<T>;
  dataSource: T[];
  loading?: boolean;
  pagination?: PaginationInfo;
  searchable?: boolean;
  searchPlaceholder?: string;
  filterable?: boolean;
  filterOptions?: Array<{
    key: string;
    label: string;
    options: Array<{ label: string; value: string }>;
  }>;
  dateRangeable?: boolean;
  dateRangeLabel?: string;
  onParamsChange?: (params: QueryParams) => void;
  onRefresh?: () => void;
  title?: string;
  extra?: React.ReactNode;
}

function DataTable<T extends Record<string, any>>({
  columns,
  dataSource,
  loading = false,
  pagination,
  searchable = true,
  searchPlaceholder = '搜索...',
  filterable = false,
  filterOptions = [],
  dateRangeable = false,
  dateRangeLabel = '时间范围',
  onParamsChange,
  onRefresh,
  title,
  extra,
  ...tableProps
}: DataTableProps<T>) {
  const [searchValue, setSearchValue] = React.useState<string>('');
  const [filters, setFilters] = React.useState<Record<string, any>>({});
  const [dateRange, setDateRange] = React.useState<[string, string] | null>(null);

  const handleSearch = (value: string) => {
    setSearchValue(value);
    onParamsChange?.({
      search: value,
      page: 1,
      ...filters,
      ...(dateRange && { dateFrom: dateRange[0], dateTo: dateRange[1] }),
    });
  };

  const handleFilterChange = (key: string, value: any) => {
    const newFilters = { ...filters, [key]: value };
    setFilters(newFilters);
    onParamsChange?.({
      search: searchValue,
      page: 1,
      ...newFilters,
      ...(dateRange && { dateFrom: dateRange[0], dateTo: dateRange[1] }),
    });
  };

  const handleDateRangeChange = (dates: any, dateStrings: [string, string]) => {
    const range = dates ? dateStrings : null;
    setDateRange(range);
    onParamsChange?.({
      search: searchValue,
      page: 1,
      ...filters,
      ...(range && { dateFrom: range[0], dateTo: range[1] }),
    });
  };

  const handleTableChange = (paginationConfig: any, filters: any, sorter: any) => {
    const params: QueryParams = {
      page: paginationConfig.current,
      limit: paginationConfig.pageSize,
      search: searchValue,
      ...filters,
    };

    if (sorter.field) {
      params.sortBy = sorter.field;
      params.sortOrder = sorter.order === 'ascend' ? 'asc' : 'desc';
    }

    if (dateRange) {
      params.dateFrom = dateRange[0];
      params.dateTo = dateRange[1];
    }

    onParamsChange?.(params);
  };

  const paginationConfig = pagination
    ? {
        current: pagination.page,
        pageSize: pagination.limit,
        total: pagination.total,
        showSizeChanger: true,
        showQuickJumper: true,
        showTotal: (total: number, range: [number, number]) =>
          `第 ${range[0]}-${range[1]} 条，共 ${total} 条`,
        pageSizeOptions: PAGINATION.PAGE_SIZE_OPTIONS.map(String),
      }
    : false;

  return (
    <Card
      title={title}
      extra={
        <Space>
          {extra}
          {onRefresh && (
            <Button
              icon={<ReloadOutlined />}
              onClick={onRefresh}
              type="text"
              size="small"
            >
              刷新
            </Button>
          )}
        </Space>
      }
    >
      {(searchable || filterable || dateRangeable) && (
        <div style={{ marginBottom: 16 }}>
          <Row gutter={[16, 16]}>
            {searchable && (
              <Col xs={24} sm={12} md={8}>
                <Search
                  placeholder={searchPlaceholder}
                  allowClear
                  onSearch={handleSearch}
                  style={{ width: '100%' }}
                />
              </Col>
            )}

            {filterable &&
              filterOptions.map((filter) => (
                <Col xs={24} sm={12} md={6} key={filter.key}>
                  <Select
                    placeholder={filter.label}
                    allowClear
                    style={{ width: '100%' }}
                    onChange={(value) => handleFilterChange(filter.key, value)}
                    options={filter.options}
                  />
                </Col>
              ))}

            {dateRangeable && (
              <Col xs={24} sm={12} md={8}>
                <RangePicker
                  placeholder={['开始日期', '结束日期']}
                  style={{ width: '100%' }}
                  onChange={handleDateRangeChange}
                />
              </Col>
            )}
          </Row>
        </div>
      )}

      <Table
        {...tableProps}
        columns={columns}
        dataSource={dataSource}
        loading={loading}
        pagination={paginationConfig}
        onChange={handleTableChange}
        scroll={{ x: 'max-content' }}
      />
    </Card>
  );
}

export default DataTable; 