import React, { useState, useEffect } from 'react';
import { Row, Col, Card, Statistic, Progress, List, Avatar, Tag, Typography, Space, Button } from 'antd';
import {
  UserOutlined,
  PhoneOutlined,
  FileTextOutlined,
  DollarOutlined,
  ArrowUpOutlined,
  ArrowDownOutlined,
  ClockCircleOutlined,
  TeamOutlined,
} from '@ant-design/icons';
import { Line, Column, Pie } from '@ant-design/plots';
import { useAppState } from '@/store';
import { apiService } from '@/services/api';
import { formatCurrency, formatNumber } from '@/utils';

const { Title, Text } = Typography;

interface DashboardStats {
  totalUsers: number;
  totalCalls: number;
  totalRevenue: number;
  totalDocuments: number;
  userGrowth: number;
  callGrowth: number;
  revenueGrowth: number;
  documentGrowth: number;
  activeTranslators: number;
  avgCallDuration: number;
  completionRate: number;
  satisfactionRate: number;
}

interface RecentActivity {
  id: string;
  type: 'call' | 'document' | 'user';
  title: string;
  description: string;
  time: string;
  status: string;
  avatar?: string;
}

const Dashboard: React.FC = () => {
  const { loading, setLoading } = useAppState();
  const [stats, setStats] = useState<DashboardStats | null>(null);
  const [recentActivities, setRecentActivities] = useState<RecentActivity[]>([]);
  const [callTrends, setCallTrends] = useState<any[]>([]);
  const [revenueTrends, setRevenueTrends] = useState<any[]>([]);
  const [languageDistribution, setLanguageDistribution] = useState<any[]>([]);

  // 获取仪表板数据
  const fetchDashboardData = async () => {
    try {
      setLoading(true);
      const [statsRes, activitiesRes, trendsRes] = await Promise.all([
        apiService.getDashboardStats(),
        apiService.getRecentActivities(),
        apiService.getDashboardTrends(),
      ]);

      setStats(statsRes);
      setRecentActivities(activitiesRes);
      setCallTrends(trendsRes.callTrends);
      setRevenueTrends(trendsRes.revenueTrends);
      setLanguageDistribution(trendsRes.languageDistribution);
    } catch (error) {
      console.error('获取仪表板数据失败:', error);
    } finally {
      setLoading(false);
    }
  };

  // 统计卡片配置
  const getStatisticCards = () => {
    if (!stats) return [];

    return [
      {
        title: '总用户数',
        value: stats.totalUsers,
        icon: <UserOutlined style={{ color: '#1890ff' }} />,
        growth: stats.userGrowth,
        color: '#1890ff',
      },
      {
        title: '总通话数',
        value: stats.totalCalls,
        icon: <PhoneOutlined style={{ color: '#52c41a' }} />,
        growth: stats.callGrowth,
        color: '#52c41a',
      },
      {
        title: '总收入',
        value: stats.totalRevenue,
        prefix: '¥',
        formatter: (value: number) => formatCurrency(value),
        icon: <DollarOutlined style={{ color: '#faad14' }} />,
        growth: stats.revenueGrowth,
        color: '#faad14',
      },
      {
        title: '文档数量',
        value: stats.totalDocuments,
        icon: <FileTextOutlined style={{ color: '#722ed1' }} />,
        growth: stats.documentGrowth,
        color: '#722ed1',
      },
    ];
  };

  // 性能指标配置
  const getPerformanceMetrics = () => {
    if (!stats) return [];

    return [
      {
        title: '活跃译员',
        value: stats.activeTranslators,
        icon: <TeamOutlined />,
        color: '#1890ff',
      },
      {
        title: '平均通话时长',
        value: `${Math.round(stats.avgCallDuration / 60)}分钟`,
        icon: <ClockCircleOutlined />,
        color: '#52c41a',
      },
      {
        title: '完成率',
        value: stats.completionRate,
        suffix: '%',
        icon: <ArrowUpOutlined />,
        color: '#faad14',
      },
      {
        title: '满意度',
        value: stats.satisfactionRate,
        suffix: '%',
        icon: <ArrowUpOutlined />,
        color: '#f5222d',
      },
    ];
  };

  // 通话趋势图配置
  const callTrendConfig = {
    data: callTrends,
    xField: 'date',
    yField: 'count',
    point: {
      size: 3,
      shape: 'circle',
    },
    color: '#1890ff',
    smooth: true,
  };

  // 收入趋势图配置
  const revenueTrendConfig = {
    data: revenueTrends,
    xField: 'date',
    yField: 'revenue',
    color: '#52c41a',
    columnStyle: {
      radius: [4, 4, 0, 0],
    },
  };

  // 语言分布饼图配置
  const languageDistributionConfig = {
    data: languageDistribution,
    angleField: 'value',
    colorField: 'language',
    radius: 0.8,
    innerRadius: 0.6,
    label: {
      type: 'inner',
      offset: '-30%',
      content: ({ percent }: any) => `${(percent * 100).toFixed(0)}%`,
      style: {
        fontSize: 14,
        textAlign: 'center',
      },
    },
  };

  // 获取活动类型图标
  const getActivityIcon = (type: string) => {
    switch (type) {
      case 'call':
        return <PhoneOutlined style={{ color: '#1890ff' }} />;
      case 'document':
        return <FileTextOutlined style={{ color: '#722ed1' }} />;
      case 'user':
        return <UserOutlined style={{ color: '#52c41a' }} />;
      default:
        return <UserOutlined />;
    }
  };

  // 获取状态标签颜色
  const getStatusColor = (status: string) => {
    switch (status) {
      case 'completed':
        return 'success';
      case 'pending':
        return 'warning';
      case 'failed':
        return 'error';
      default:
        return 'default';
    }
  };

  useEffect(() => {
    fetchDashboardData();
  }, []);

  return (
    <div>
      {/* 统计卡片 */}
      <Row gutter={[16, 16]} style={{ marginBottom: 24 }}>
        {getStatisticCards().map((card, index) => (
          <Col xs={24} sm={12} lg={6} key={index}>
            <Card>
              <Statistic
                title={card.title}
                value={card.value}
                prefix={card.prefix}
                formatter={card.formatter}
                valueStyle={{ color: card.color }}
              />
              <div style={{ marginTop: 8, display: 'flex', alignItems: 'center' }}>
                {card.icon}
                <span style={{ marginLeft: 8 }}>
                  {card.growth > 0 ? (
                    <Text type="success">
                      <ArrowUpOutlined /> {card.growth}%
                    </Text>
                  ) : (
                    <Text type="danger">
                      <ArrowDownOutlined /> {Math.abs(card.growth)}%
                    </Text>
                  )}
                  <Text type="secondary" style={{ marginLeft: 4 }}>
                    较上月
                  </Text>
                </span>
              </div>
            </Card>
          </Col>
        ))}
      </Row>

      {/* 性能指标 */}
      <Row gutter={[16, 16]} style={{ marginBottom: 24 }}>
        {getPerformanceMetrics().map((metric, index) => (
          <Col xs={24} sm={12} lg={6} key={index}>
            <Card>
              <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'space-between' }}>
                <div>
                  <Text type="secondary">{metric.title}</Text>
                  <div style={{ fontSize: '24px', fontWeight: 'bold', color: metric.color }}>
                    {metric.value}{metric.suffix}
                  </div>
                </div>
                <div style={{ fontSize: '24px', color: metric.color }}>
                  {metric.icon}
                </div>
              </div>
              {metric.title === '完成率' && (
                <Progress 
                  percent={stats?.completionRate || 0} 
                  showInfo={false} 
                  strokeColor={metric.color}
                  style={{ marginTop: 8 }}
                />
              )}
              {metric.title === '满意度' && (
                <Progress 
                  percent={stats?.satisfactionRate || 0} 
                  showInfo={false} 
                  strokeColor={metric.color}
                  style={{ marginTop: 8 }}
                />
              )}
            </Card>
          </Col>
        ))}
      </Row>

      {/* 图表区域 */}
      <Row gutter={[16, 16]} style={{ marginBottom: 24 }}>
        <Col xs={24} lg={12}>
          <Card title="通话趋势" loading={loading}>
            <Line {...callTrendConfig} height={300} />
          </Card>
        </Col>
        <Col xs={24} lg={12}>
          <Card title="收入趋势" loading={loading}>
            <Column {...revenueTrendConfig} height={300} />
          </Card>
        </Col>
      </Row>

      <Row gutter={[16, 16]}>
        <Col xs={24} lg={8}>
          <Card title="语言分布" loading={loading}>
            <Pie {...languageDistributionConfig} height={300} />
          </Card>
        </Col>
        <Col xs={24} lg={16}>
          <Card 
            title="最近活动" 
            loading={loading}
            extra={
              <Button type="link" onClick={fetchDashboardData}>
                刷新
              </Button>
            }
          >
            <List
              itemLayout="horizontal"
              dataSource={recentActivities}
              renderItem={(item) => (
                <List.Item>
                  <List.Item.Meta
                    avatar={
                      <Avatar 
                        src={item.avatar} 
                        icon={getActivityIcon(item.type)}
                      />
                    }
                    title={
                      <Space>
                        <span>{item.title}</span>
                        <Tag color={getStatusColor(item.status)}>
                          {item.status}
                        </Tag>
                      </Space>
                    }
                    description={
                      <div>
                        <div>{item.description}</div>
                        <Text type="secondary" style={{ fontSize: '12px' }}>
                          {item.time}
                        </Text>
                      </div>
                    }
                  />
                </List.Item>
              )}
            />
          </Card>
        </Col>
      </Row>
    </div>
  );
};

export default Dashboard; 