import { Row, Col, Card, Statistic, Typography, Table, Progress, Tag, Space } from 'antd';
import {
  UserOutlined,
  PhoneOutlined,
  DollarOutlined,
  RiseOutlined,
  DownOutlined,
  UpOutlined,
} from '@ant-design/icons';
import { useEffect } from 'react';
import { useLoading } from '@/store';
import { formatCurrency, formatDate } from '@/utils';

const { Title, Text } = Typography;

interface DashboardStats {
  totalUsers: number;
  totalCalls: number;
  totalRevenue: number;
  monthlyGrowth: number;
}

interface RecentCall {
  id: string;
  caller: string;
  translator: string;
  language: string;
  duration: number;
  status: 'completed' | 'in-progress' | 'failed';
  timestamp: Date;
}

const Dashboard = () => {
  const { loading, setLoading } = useLoading();

  const stats: DashboardStats = {
    totalUsers: 1234,
    totalCalls: 5678,
    totalRevenue: 123456,
    monthlyGrowth: 12.5,
  };

  const recentCalls: RecentCall[] = [
    {
      id: '1',
      caller: '张三',
      translator: '李四',
      language: '英语',
      duration: 1800,
      status: 'completed',
      timestamp: new Date(),
    },
    {
      id: '2',
      caller: '王五',
      translator: '赵六',
      language: '日语',
      duration: 2400,
      status: 'in-progress',
      timestamp: new Date(),
    },
  ];

  const columns = [
    {
      title: '呼叫者',
      dataIndex: 'caller',
      key: 'caller',
    },
    {
      title: '译员',
      dataIndex: 'translator',
      key: 'translator',
    },
    {
      title: '语言',
      dataIndex: 'language',
      key: 'language',
    },
    {
      title: '时长',
      dataIndex: 'duration',
      key: 'duration',
      render: (duration: number) => `${Math.floor(duration / 60)}分钟`,
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (status: string) => {
        const statusMap = {
          completed: { color: 'green', text: '已完成' },
          'in-progress': { color: 'blue', text: '进行中' },
          failed: { color: 'red', text: '失败' },
        };
        const statusInfo = statusMap[status as keyof typeof statusMap];
        return <Tag color={statusInfo.color}>{statusInfo.text}</Tag>;
      },
    },
    {
      title: '时间',
      dataIndex: 'timestamp',
      key: 'timestamp',
      render: (timestamp: Date) => formatDate(timestamp),
    },
  ];

  useEffect(() => {
    setLoading(true);
    // 模拟数据加载
    setTimeout(() => {
      setLoading(false);
    }, 1000);
  }, [setLoading]);

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>仪表板</Title>
      
      <Row gutter={[16, 16]} style={{ marginBottom: '24px' }}>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="总用户数"
              value={stats.totalUsers}
              prefix={<UserOutlined />}
              valueStyle={{ color: '#3f8600' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="总通话数"
              value={stats.totalCalls}
              prefix={<PhoneOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalRevenue}
              prefix={<DollarOutlined />}
              formatter={(value) => formatCurrency(Number(value))}
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="月增长率"
              value={stats.monthlyGrowth}
              prefix={stats.monthlyGrowth > 0 ? <RiseOutlined /> : <DownOutlined />}
              suffix="%"
              valueStyle={{ 
                color: stats.monthlyGrowth > 0 ? '#3f8600' : '#cf1322' 
              }}
            />
          </Card>
        </Col>
      </Row>

      <Row gutter={[16, 16]}>
        <Col xs={24} lg={16}>
          <Card title="最近通话记录" loading={loading}>
            <Table
              columns={columns}
              dataSource={recentCalls}
              rowKey="id"
              pagination={false}
              size="small"
            />
          </Card>
        </Col>
        <Col xs={24} lg={8}>
          <Card title="系统状态">
            <Space direction="vertical" style={{ width: '100%' }}>
              <div>
                <Text>CPU 使用率</Text>
                <Progress percent={30} size="small" />
              </div>
              <div>
                <Text>内存使用率</Text>
                <Progress percent={60} size="small" />
              </div>
              <div>
                <Text>磁盘使用率</Text>
                <Progress percent={80} size="small" />
              </div>
            </Space>
          </Card>
        </Col>
      </Row>
    </div>
  );
};

export default Dashboard; 