import React, { useState, useEffect } from 'react';
import {
  View,
  Text,
  StyleSheet,
  TouchableOpacity,
  ScrollView,
  SafeAreaView,
  Alert,
  ActivityIndicator,
  Modal,
  TextInput,
} from 'react-native';
import { mockDocuments, mockLanguages } from '@/utils/mockData';
import { DocumentTranslation, Language } from '@/types';

interface DocumentScreenProps {
  navigation?: any;
}

const DocumentScreen: React.FC<DocumentScreenProps> = ({ navigation }) => {
  const [documents, setDocuments] = useState<DocumentTranslation[]>([]);
  const [isLoading, setIsLoading] = useState(true);
  const [uploadModalVisible, setUploadModalVisible] = useState(false);
  const [selectedLanguages, setSelectedLanguages] = useState({
    source: 'zh',
    target: 'en',
  });
  const [uploadProgress, setUploadProgress] = useState(0);
  const [isUploading, setIsUploading] = useState(false);

  useEffect(() => {
    loadDocuments();
  }, []);

  const loadDocuments = async () => {
    try {
      setIsLoading(true);
      // 模拟API调用
      setTimeout(() => {
        setDocuments(mockDocuments);
        setIsLoading(false);
      }, 1000);
    } catch (error) {
      console.error('Failed to load documents:', error);
      setIsLoading(false);
    }
  };

  const getLanguageInfo = (code: string): Language | undefined => {
    return mockLanguages.find(lang => lang.code === code);
  };

  const getStatusColor = (status: string): string => {
    const colorMap: { [key: string]: string } = {
      pending: '#FF9800',
      processing: '#2196F3',
      completed: '#4CAF50',
      failed: '#F44336',
    };
    return colorMap[status] || '#999';
  };

  const getStatusText = (status: string): string => {
    const textMap: { [key: string]: string } = {
      pending: '等待中',
      processing: '翻译中',
      completed: '已完成',
      failed: '失败',
    };
    return textMap[status] || status;
  };

  const formatFileSize = (bytes: number): string => {
    if (bytes === 0) return '0 B';
    const k = 1024;
    const sizes = ['B', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
  };

  const handleUploadDocument = () => {
    setUploadModalVisible(true);
  };

  const handleFileSelect = async () => {
    try {
      setIsUploading(true);
      setUploadProgress(0);
      
      // 模拟文件选择和上传过程
      // const result = await DocumentPicker.pick({
      //   type: [DocumentPicker.types.pdf, DocumentPicker.types.doc, DocumentPicker.types.docx],
      // });
      
      // 模拟上传进度
      const uploadInterval = setInterval(() => {
        setUploadProgress(prev => {
          if (prev >= 100) {
            clearInterval(uploadInterval);
            completeUpload();
            return 100;
          }
          return prev + 10;
        });
      }, 200);
      
    } catch (error) {
      console.error('File selection failed:', error);
      setIsUploading(false);
    }
  };

  const completeUpload = () => {
    const newDocument: DocumentTranslation = {
      id: `doc-${Date.now()}`,
      userId: 'user-123',
      originalFileName: '示例文档.pdf',
      originalFileUrl: 'https://example.com/original.pdf',
      sourceLanguage: selectedLanguages.source,
      targetLanguage: selectedLanguages.target,
      status: 'pending',
      fileSize: 1024 * 1024 * 2.5,
      pageCount: 10,
      cost: 25.00,
      createdAt: new Date().toISOString(),
    };

    setDocuments(prev => [newDocument, ...prev]);
    setIsUploading(false);
    setUploadModalVisible(false);
    setUploadProgress(0);
    
    Alert.alert('上传成功', '文档已上传，正在处理翻译...');
  };

  const handleDownload = (document: DocumentTranslation) => {
    if (document.status === 'completed' && document.translatedFileUrl) {
      Alert.alert(
        '下载文档',
        `是否下载翻译后的文档：${document.translatedFileName || '翻译文档.pdf'}？`,
        [
          { text: '取消', style: 'cancel' },
          { 
            text: '下载', 
            onPress: () => {
              // 在实际应用中实现文件下载
              Alert.alert('下载开始', '文档正在下载...');
            }
          },
        ]
      );
    } else {
      Alert.alert('无法下载', '文档尚未翻译完成');
    }
  };

  const handleRetry = (document: DocumentTranslation) => {
    Alert.alert(
      '重新翻译',
      '是否重新翻译此文档？',
      [
        { text: '取消', style: 'cancel' },
        { 
          text: '确定', 
          onPress: () => {
            // 更新文档状态为处理中
            setDocuments(prev => 
              prev.map(doc => 
                doc.id === document.id 
                  ? { ...doc, status: 'processing' }
                  : doc
              )
            );
          }
        },
      ]
    );
  };

  const renderLanguageSelector = () => (
    <View style={styles.languageSelector}>
      <Text style={styles.sectionTitle}>选择翻译语言</Text>
      <View style={styles.languageRow}>
        <View style={styles.languageOption}>
          <Text style={styles.languageLabel}>源语言</Text>
          <TouchableOpacity style={styles.languageButton}>
            <Text style={styles.languageButtonText}>
              {getLanguageInfo(selectedLanguages.source)?.nativeName || '中文'}
            </Text>
          </TouchableOpacity>
        </View>
        <Text style={styles.arrowText}>→</Text>
        <View style={styles.languageOption}>
          <Text style={styles.languageLabel}>目标语言</Text>
          <TouchableOpacity style={styles.languageButton}>
            <Text style={styles.languageButtonText}>
              {getLanguageInfo(selectedLanguages.target)?.nativeName || 'English'}
            </Text>
          </TouchableOpacity>
        </View>
      </View>
    </View>
  );

  const renderUploadModal = () => (
    <Modal
      visible={uploadModalVisible}
      transparent
      animationType="slide"
      onRequestClose={() => setUploadModalVisible(false)}
    >
      <View style={styles.modalOverlay}>
        <View style={styles.modalContent}>
          <Text style={styles.modalTitle}>上传文档</Text>
          
          {renderLanguageSelector()}
          
          <View style={styles.uploadArea}>
            {isUploading ? (
              <View style={styles.uploadingContainer}>
                <ActivityIndicator size="large" color="#2196F3" />
                <Text style={styles.uploadingText}>上传中... {uploadProgress}%</Text>
                <View style={styles.progressBar}>
                  <View 
                    style={[styles.progressFill, { width: `${uploadProgress}%` }]} 
                  />
                </View>
              </View>
            ) : (
              <TouchableOpacity style={styles.uploadButton} onPress={handleFileSelect}>
                <Text style={styles.uploadIcon}>📄</Text>
                <Text style={styles.uploadText}>选择文档</Text>
                <Text style={styles.uploadSubtext}>支持 PDF, DOC, DOCX 格式</Text>
              </TouchableOpacity>
            )}
          </View>
          
          <View style={styles.modalActions}>
            <TouchableOpacity 
              style={[styles.modalButton, styles.cancelButton]}
              onPress={() => setUploadModalVisible(false)}
              disabled={isUploading}
            >
              <Text style={styles.cancelButtonText}>取消</Text>
            </TouchableOpacity>
          </View>
        </View>
      </View>
    </Modal>
  );

  const renderDocumentItem = (document: DocumentTranslation) => {
    const sourceLang = getLanguageInfo(document.sourceLanguage);
    const targetLang = getLanguageInfo(document.targetLanguage);
    
    return (
      <View key={document.id} style={styles.documentItem}>
        <View style={styles.documentHeader}>
          <View style={styles.documentInfo}>
            <Text style={styles.fileName}>{document.originalFileName}</Text>
            <Text style={styles.languageInfo}>
              {sourceLang?.flag} {sourceLang?.nativeName} → {targetLang?.flag} {targetLang?.nativeName}
            </Text>
          </View>
          <View style={[styles.statusBadge, { backgroundColor: getStatusColor(document.status) }]}>
            <Text style={styles.statusText}>{getStatusText(document.status)}</Text>
          </View>
        </View>
        
        <View style={styles.documentDetails}>
          <Text style={styles.detailText}>
            大小: {formatFileSize(document.fileSize || 0)}
          </Text>
          {document.pageCount && (
            <Text style={styles.detailText}>
              页数: {document.pageCount}
            </Text>
          )}
          <Text style={styles.detailText}>
            费用: ¥{document.cost?.toFixed(2) || '0.00'}
          </Text>
        </View>
        
        {document.status === 'processing' && (
          <View style={styles.progressContainer}>
            <Text style={styles.progressText}>翻译进度: {document.progress || 0}%</Text>
            <View style={styles.progressBar}>
              <View 
                style={[styles.progressFill, { width: `${document.progress || 0}%` }]} 
              />
            </View>
          </View>
        )}
        
        <View style={styles.documentActions}>
          {document.status === 'completed' && (
            <TouchableOpacity 
              style={[styles.actionButton, styles.downloadButton]}
              onPress={() => handleDownload(document)}
            >
              <Text style={styles.actionButtonText}>下载</Text>
            </TouchableOpacity>
          )}
          {document.status === 'failed' && (
            <TouchableOpacity 
              style={[styles.actionButton, styles.retryButton]}
              onPress={() => handleRetry(document)}
            >
              <Text style={styles.actionButtonText}>重试</Text>
            </TouchableOpacity>
          )}
        </View>
      </View>
    );
  };

  if (isLoading) {
    return (
      <SafeAreaView style={styles.container}>
        <View style={styles.loadingContainer}>
          <ActivityIndicator size="large" color="#2196F3" />
          <Text style={styles.loadingText}>加载文档列表...</Text>
        </View>
      </SafeAreaView>
    );
  }

  return (
    <SafeAreaView style={styles.container}>
      <View style={styles.header}>
        <Text style={styles.headerTitle}>文档翻译</Text>
        <TouchableOpacity style={styles.uploadHeaderButton} onPress={handleUploadDocument}>
          <Text style={styles.uploadHeaderButtonText}>+ 上传</Text>
        </TouchableOpacity>
      </View>
      
      <ScrollView style={styles.content} showsVerticalScrollIndicator={false}>
        {documents.length === 0 ? (
          <View style={styles.emptyContainer}>
            <Text style={styles.emptyIcon}>📄</Text>
            <Text style={styles.emptyTitle}>暂无文档</Text>
            <Text style={styles.emptySubtitle}>上传您的第一个文档开始翻译</Text>
            <TouchableOpacity style={styles.emptyButton} onPress={handleUploadDocument}>
              <Text style={styles.emptyButtonText}>上传文档</Text>
            </TouchableOpacity>
          </View>
        ) : (
          <View style={styles.documentList}>
            {documents.map(renderDocumentItem)}
          </View>
        )}
      </ScrollView>
      
      {renderUploadModal()}
    </SafeAreaView>
  );
};

const styles = StyleSheet.create({
  container: {
    flex: 1,
    backgroundColor: '#f5f5f5',
  },
  header: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: 16,
    backgroundColor: '#fff',
    borderBottomWidth: 1,
    borderBottomColor: '#e0e0e0',
  },
  headerTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
  },
  uploadHeaderButton: {
    backgroundColor: '#2196F3',
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 20,
  },
  uploadHeaderButtonText: {
    color: '#fff',
    fontSize: 14,
    fontWeight: 'bold',
  },
  content: {
    flex: 1,
    padding: 16,
  },
  loadingContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
  },
  loadingText: {
    marginTop: 16,
    fontSize: 16,
    color: '#666',
  },
  emptyContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    paddingTop: 100,
  },
  emptyIcon: {
    fontSize: 80,
    marginBottom: 16,
  },
  emptyTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 8,
  },
  emptySubtitle: {
    fontSize: 16,
    color: '#666',
    marginBottom: 32,
    textAlign: 'center',
  },
  emptyButton: {
    backgroundColor: '#2196F3',
    paddingHorizontal: 32,
    paddingVertical: 12,
    borderRadius: 24,
  },
  emptyButtonText: {
    color: '#fff',
    fontSize: 16,
    fontWeight: 'bold',
  },
  documentList: {
    gap: 16,
  },
  documentItem: {
    backgroundColor: '#fff',
    borderRadius: 12,
    padding: 16,
    shadowColor: '#000',
    shadowOffset: { width: 0, height: 2 },
    shadowOpacity: 0.1,
    shadowRadius: 4,
    elevation: 3,
  },
  documentHeader: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'flex-start',
    marginBottom: 12,
  },
  documentInfo: {
    flex: 1,
    marginRight: 12,
  },
  fileName: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 4,
  },
  languageInfo: {
    fontSize: 14,
    color: '#666',
  },
  statusBadge: {
    paddingHorizontal: 8,
    paddingVertical: 4,
    borderRadius: 12,
  },
  statusText: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
  },
  documentDetails: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    marginBottom: 12,
  },
  detailText: {
    fontSize: 12,
    color: '#666',
  },
  progressContainer: {
    marginBottom: 12,
  },
  progressText: {
    fontSize: 12,
    color: '#666',
    marginBottom: 4,
  },
  progressBar: {
    height: 4,
    backgroundColor: '#e0e0e0',
    borderRadius: 2,
    overflow: 'hidden',
  },
  progressFill: {
    height: '100%',
    backgroundColor: '#2196F3',
  },
  documentActions: {
    flexDirection: 'row',
    justifyContent: 'flex-end',
  },
  actionButton: {
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 16,
    marginLeft: 8,
  },
  downloadButton: {
    backgroundColor: '#4CAF50',
  },
  retryButton: {
    backgroundColor: '#FF9800',
  },
  actionButtonText: {
    color: '#fff',
    fontSize: 12,
    fontWeight: 'bold',
  },
  modalOverlay: {
    flex: 1,
    backgroundColor: 'rgba(0, 0, 0, 0.5)',
    justifyContent: 'center',
    alignItems: 'center',
  },
  modalContent: {
    backgroundColor: '#fff',
    borderRadius: 16,
    padding: 24,
    width: '90%',
    maxWidth: 400,
  },
  modalTitle: {
    fontSize: 20,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 24,
    textAlign: 'center',
  },
  languageSelector: {
    marginBottom: 24,
  },
  sectionTitle: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#333',
    marginBottom: 12,
  },
  languageRow: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between',
  },
  languageOption: {
    flex: 1,
  },
  languageLabel: {
    fontSize: 12,
    color: '#666',
    marginBottom: 4,
  },
  languageButton: {
    backgroundColor: '#f0f0f0',
    padding: 12,
    borderRadius: 8,
    alignItems: 'center',
  },
  languageButtonText: {
    fontSize: 14,
    color: '#333',
  },
  arrowText: {
    fontSize: 20,
    color: '#666',
    marginHorizontal: 16,
  },
  uploadArea: {
    marginBottom: 24,
  },
  uploadButton: {
    borderWidth: 2,
    borderColor: '#2196F3',
    borderStyle: 'dashed',
    borderRadius: 12,
    padding: 32,
    alignItems: 'center',
  },
  uploadIcon: {
    fontSize: 48,
    marginBottom: 12,
  },
  uploadText: {
    fontSize: 16,
    fontWeight: 'bold',
    color: '#2196F3',
    marginBottom: 4,
  },
  uploadSubtext: {
    fontSize: 12,
    color: '#666',
  },
  uploadingContainer: {
    alignItems: 'center',
    padding: 32,
  },
  uploadingText: {
    fontSize: 16,
    color: '#333',
    marginTop: 12,
    marginBottom: 16,
  },
  modalActions: {
    flexDirection: 'row',
    justifyContent: 'center',
  },
  modalButton: {
    paddingHorizontal: 24,
    paddingVertical: 12,
    borderRadius: 24,
    minWidth: 80,
    alignItems: 'center',
  },
  cancelButton: {
    backgroundColor: '#f0f0f0',
  },
  cancelButtonText: {
    color: '#666',
    fontSize: 14,
    fontWeight: 'bold',
  },
});

export default DocumentScreen; 