import axios, { AxiosInstance, AxiosResponse } from 'axios';
import { ApiResponse } from '@/types';
import { getToken, removeToken } from '@/utils/storage';

class DatabaseService {
  private api: AxiosInstance;
  private baseURL: string;

  constructor() {
    this.baseURL = __DEV__ 
      ? 'http://localhost:3000/api' 
      : 'https://api.translatepro.com/api';
    
    this.api = axios.create({
      baseURL: this.baseURL,
      timeout: 10000,
      headers: {
        'Content-Type': 'application/json',
      },
    });

    this.setupInterceptors();
  }

  private setupInterceptors() {
    // 请求拦截器 - 添加认证token
    this.api.interceptors.request.use(
      async (config) => {
        const token = await getToken();
        if (token) {
          config.headers.Authorization = `Bearer ${token}`;
        }
        return config;
      },
      (error) => {
        return Promise.reject(error);
      }
    );

    // 响应拦截器 - 处理认证错误
    this.api.interceptors.response.use(
      (response: AxiosResponse) => {
        return response;
      },
      async (error) => {
        if (error.response?.status === 401) {
          await removeToken();
          // 可以在这里触发登录页面跳转
        }
        return Promise.reject(error);
      }
    );
  }

  // 通用GET请求
  async get<T>(endpoint: string, params?: any): Promise<ApiResponse<T>> {
    try {
      const response = await this.api.get(endpoint, { params });
      return response.data;
    } catch (error: any) {
      return this.handleError(error);
    }
  }

  // 通用POST请求
  async post<T>(endpoint: string, data?: any): Promise<ApiResponse<T>> {
    try {
      const response = await this.api.post(endpoint, data);
      return response.data;
    } catch (error: any) {
      return this.handleError(error);
    }
  }

  // 通用PUT请求
  async put<T>(endpoint: string, data?: any): Promise<ApiResponse<T>> {
    try {
      const response = await this.api.put(endpoint, data);
      return response.data;
    } catch (error: any) {
      return this.handleError(error);
    }
  }

  // 通用DELETE请求
  async delete<T>(endpoint: string): Promise<ApiResponse<T>> {
    try {
      const response = await this.api.delete(endpoint);
      return response.data;
    } catch (error: any) {
      return this.handleError(error);
    }
  }

  // 文件上传
  async uploadFile<T>(
    endpoint: string, 
    file: any, 
    onProgress?: (progress: number) => void
  ): Promise<ApiResponse<T>> {
    try {
      const formData = new FormData();
      formData.append('file', file);

      const response = await this.api.post(endpoint, formData, {
        headers: {
          'Content-Type': 'multipart/form-data',
        },
        onUploadProgress: (progressEvent) => {
          if (onProgress && progressEvent.total) {
            const progress = Math.round(
              (progressEvent.loaded * 100) / progressEvent.total
            );
            onProgress(progress);
          }
        },
      });

      return response.data;
    } catch (error: any) {
      return this.handleError(error);
    }
  }

  // 错误处理
  private handleError(error: any): ApiResponse<any> {
    console.error('API Error:', error);
    
    if (error.response) {
      // 服务器响应错误
      return {
        success: false,
        error: error.response.data?.message || '服务器错误',
        message: error.response.data?.message || '请求失败',
      };
    } else if (error.request) {
      // 网络错误
      return {
        success: false,
        error: '网络连接失败',
        message: '请检查网络连接',
      };
    } else {
      // 其他错误
      return {
        success: false,
        error: error.message || '未知错误',
        message: '请求处理失败',
      };
    }
  }

  // 获取API实例（用于特殊情况）
  getApiInstance(): AxiosInstance {
    return this.api;
  }

  // 更新baseURL（用于环境切换）
  updateBaseURL(newBaseURL: string) {
    this.baseURL = newBaseURL;
    this.api.defaults.baseURL = newBaseURL;
  }
}

// 导出单例实例
export const databaseService = new DatabaseService();
export default databaseService; 