import * as Keychain from 'react-native-keychain';
import AsyncStorage from '@react-native-async-storage/async-storage';

// 安全存储（用于敏感信息如token）
export const setToken = async (token: string): Promise<void> => {
  try {
    await Keychain.setInternetCredentials(
      'TranslatePro',
      'auth_token',
      token
    );
  } catch (error) {
    console.error('Error storing token:', error);
  }
};

export const getToken = async (): Promise<string | null> => {
  try {
    const credentials = await Keychain.getInternetCredentials('TranslatePro');
    if (credentials) {
      return credentials.password;
    }
    return null;
  } catch (error) {
    console.error('Error retrieving token:', error);
    return null;
  }
};

export const removeToken = async (): Promise<void> => {
  try {
    await Keychain.resetInternetCredentials('TranslatePro');
  } catch (error) {
    console.error('Error removing token:', error);
  }
};

// 普通存储（用于非敏感信息）
export const setStorageItem = async (key: string, value: any): Promise<void> => {
  try {
    const jsonValue = JSON.stringify(value);
    await AsyncStorage.setItem(key, jsonValue);
  } catch (error) {
    console.error('Error storing item:', error);
  }
};

export const getStorageItem = async <T>(key: string): Promise<T | null> => {
  try {
    const jsonValue = await AsyncStorage.getItem(key);
    return jsonValue != null ? JSON.parse(jsonValue) : null;
  } catch (error) {
    console.error('Error retrieving item:', error);
    return null;
  }
};

export const removeStorageItem = async (key: string): Promise<void> => {
  try {
    await AsyncStorage.removeItem(key);
  } catch (error) {
    console.error('Error removing item:', error);
  }
};

export const clearAllStorage = async (): Promise<void> => {
  try {
    await AsyncStorage.clear();
    await Keychain.resetInternetCredentials('TranslatePro');
  } catch (error) {
    console.error('Error clearing storage:', error);
  }
};

// 存储键常量
export const STORAGE_KEYS = {
  USER_PREFERENCES: 'user_preferences',
  LANGUAGE_SETTINGS: 'language_settings',
  CALL_HISTORY: 'call_history',
  DOCUMENT_CACHE: 'document_cache',
  NOTIFICATION_SETTINGS: 'notification_settings',
} as const; 